@@ -1,5 +1,7 @@
 """
-Main interface for dynamodb service literal definitions.
+Type annotations for dynamodb service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/literals.html)
 
 Usage::
 
